// Author: forrestfunk81@noctrl.eu
// SystemInfo gnome extension - version 0.1
// Distributed under the terms of the GNU General Public License v3

const St = imports.gi.St;
const GLib = imports.gi.GLib; 
const Mainloop = imports.mainloop;
const Main = imports.ui.main;
const Lang = imports.lang;
const PanelMenu = imports.ui.panelMenu;
const Gettext = imports.gettext;
const Util = imports.misc.util;
const GTop = imports.gi.GTop;
const PopupMenu = imports.ui.popupMenu; 
 
const _ = Gettext.gettext;
 
function SystemInfo() {
    this._init();
}

SystemInfo.prototype = {
	__proto__: PanelMenu.SystemStatusButton.prototype,
		
	// init SystemInfo
	_init: function() {
		PanelMenu.SystemStatusButton.prototype._init.call(this, 'systeminfo');
		
        this.statusLabel = new St.Label({
            text: "--",
            style_class: "systeminfo-label"
        });
        
        // destroy all previously created children, and add our statusLabel
        this.actor.get_children().forEach(function(c) {
            c.destroy();
        });
        this.actor.add_actor(this.statusLabel);

        cpuUse = 0;
        memUse = 0;
        
        this._initValues();
        this._updateUI();
        
        //update every 2 seconds
        event = GLib.timeout_add_seconds(0, 2, Lang.bind(this, function () {
            this._updateUI();
            return true;
        }));
        
        let section = new PopupMenu.PopupMenuSection("SystemInfo");
        let item = new PopupMenu.PopupMenuItem("Test");
        section.addMenuItem(item);
        this.menu.addMenuItem(section);
	},
	
	// call updateValues and update the ui
	_updateUI: function() {
		this._updateValues();
		
		cpuText = "0" + cpuUse ;
		cpuText = cpuText.substr(cpuText.length - 2, cpuText.length);		
		memText = memUse + "";
		
		this.statusLabel.set_text("CPU: " + cpuText + " % / Mem: " + memText + " %"); 
	},

	// initialize values
	_initValues: function() { 
        this._prev = new GTop.glibtop_cpu;
        GTop.glibtop_get_cpu(this._prev);
        
        this.mem = new GTop.glibtop_mem;
	},
	
	// update cpu and mem values
    _updateValues: function() { 
    	// cpu shit
        let cpu = new GTop.glibtop_cpu; 
        GTop.glibtop_get_cpu(cpu);
        let total = cpu.total - this._prev.total;
        let user = cpu.user - this._prev.user;
        let sys = cpu.sys - this._prev.sys;
        let iowait = cpu.iowait - this._prev.iowait;
        let idle = cpu.idle - this._prev.idle; 
        
        cpuUse = Math.round(100.0 * (user+sys+iowait) / total);
        this._prev = cpu;
        
        // mem
        GTop.glibtop_get_mem(this.mem);
        memUse =  Math.round(100.0 * this.mem.used / this.mem.total);          
    },
	
	_onDestroy: function() {}
};

//for debugging
function debug(a){
    global.log(a);
    Util.spawn(['echo',a]);
}

let _panelText;
let event=null;

function init() {
	_panelText = new SystemInfo();
}

function enable() {
	_panelText = new SystemInfo();
	Main.panel.addToStatusArea('systeminfo', _panelText);
}

function disable(){
	_panelText.destroy();
    Mainloop.source_remove(event);
    _panelText = null;
};